km3pipe.core.Module
===================

.. currentmodule:: km3pipe.core

.. autoclass:: Module

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Module.__init__
      ~Module.add
      ~Module.configure
      ~Module.expose
      ~Module.finish
      ~Module.get
      ~Module.pre_finish
      ~Module.process
      ~Module.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Module.name
   
   